Fix some errors that #7566 introduced on non-Windows platforms due to
an ImportError. Rearranged the import, faked out the implementation when
the import fails, and reorganized a test that depends on Win32 behavior.
diff --git a/Lib/test/test_ntpath.py b/Lib/test/test_ntpath.py
index 9f39aba..5609aee 100644
--- a/Lib/test/test_ntpath.py
+++ b/Lib/test/test_ntpath.py
@@ -1,5 +1,6 @@
 import ntpath
 import os
+import sys
 from test.support import TestFailed
 from test import support, test_genericpath
 from tempfile import TemporaryFile
@@ -244,11 +245,12 @@
             self.assertTrue(ntpath.sameopenfile(tf1.fileno(), tf1.fileno()))
             # Make sure different files are really different
             self.assertFalse(ntpath.sameopenfile(tf1.fileno(), tf2.fileno()))
-            # Make sure invalid values don't cause issues
-            with self.assertRaises(ValueError):
-                # Invalid file descriptors shouldn't display assert
-                # dialogs (#4804)
-                ntpath.sameopenfile(-1, -1)
+            # Make sure invalid values don't cause issues on win32
+            if sys.platform == "win32":
+                with self.assertRaises(ValueError):
+                    # Invalid file descriptors shouldn't display assert
+                    # dialogs (#4804)
+                    ntpath.sameopenfile(-1, -1)
 
 
 class NtCommonTest(test_genericpath.CommonTest):